@@ -193,11 +193,14 @@ class PARAMETROS:
                 elif row["des_datatype"] == "LIST":
                     row["val_parametro"] = row["val_parametro"].split(separador_listas)
                 elif row["des_datatype"] == "JSON":
-                    row["val_parametro"] = ast.literal_eval(row["val_parametro"])
+                    #row["val_parametro"] = ast.literal_eval(row["val_parametro"])
+                    row["val_parametro"] = json.loads(row["val_parametro"])
                 elif row["des_datatype"] == "LIST/JSON":
                     row["val_parametro"] = row["val_parametro"].split(separador_listas)
                     for i in range(len(row["val_parametro"])):
-                        row["val_parametro"][i] = ast.literal_eval(row["val_parametro"][i])
+                        #row["val_parametro"][i] = ast.literal_eval(row["val_parametro"][i])
+                        #row["val_parametro"][i] = ast.literal_eval(row["val_parametro"][i])
+                        row["val_parametro"][i] = json.loads(row["val_parametro"][i])
         except Exception as error:
             rs = f"""Falha na obtenção dos parametros para a FAMILIA de PARAMETROS: {des_aplicacao}.\nErro: {error}"""
         finally:
